@@ -1,33 +1,26 @@
 import pytest
 
-from radicl.serial import RAD_Serial
+from radicl.com import RAD_Serial
 from radicl.api import RAD_API
 from radicl.probe import RAD_Probe
-
 from . import MOCKCLI
 
 
-@pytest.fixture()
-def port():
+@pytest.fixture(scope='session')
+def real_port():
     port = RAD_Serial(debug=True)
     port.openPort()
     yield port
     port.closePort()
 
 
-@pytest.fixture()
-def api(port):
-    yield RAD_API(port, debug=True)
+@pytest.fixture(scope='session')
+def real_api(real_port):
+    yield RAD_API(real_port, debug=True)
 
 
-@pytest.fixture()
-def probe():
-    prb = RAD_Probe(debug=True)
-    yield prb
-
-
-@pytest.fixture()
-def meas_probe():
+@pytest.fixture(scope='session')
+def real_probe():
     """
     Probe object with a reset at the end
     """
@@ -36,6 +29,6 @@ def meas_probe():
     prb.resetMeasurement()
 
 
-@pytest.fixture(scope='session')
-def cli():
+@pytest.fixture()
+def mock_cli():
     yield MOCKCLI()
